// (c) COPYRIGHT MIT, INRIA and Keio, 2007 and onwards.
// Please first read the full copyright statement in file COPYRIGHT.html

package org.w3c.mwi.mobileok.basic;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * Abstract superclass of all {@link TestImplementation} implementations, providing some common
 * useful functionality.
 */
abstract class AbstractTestImplementation implements TestImplementation {

	static final String LINE_SEPARATOR = System.getProperty("line.separator");

	// TODO remove this dummy implementation
	public TestResult runTest(final TestContext context) {
		final TestResult result = new TestResult(getTestType());
		result.setOutcomeMessage("Test not implemented");
		result.addWarning("Test not implemented");
		return result;
	}

	static void addHeaderInfo(final String name, final String value, final TestResult result) {
		result.addInfo(name + " header: " + value);
	}

	/**
	 * <p>Parses a string representing a date in one of the following formats, which are defined
	 * by RFC 2616 as formats that must be parsed by an HTTP 1.1 server:</p>
	 *
	 * <p>Sun, 06 Nov 1994 08:49:37 GMT  ; RFC 822, updated by RFC 1123<br/>
	 * Sunday, 06-Nov-94 08:49:37 GMT ; RFC 850, obsoleted by RFC 1036<br/>
	 * Sun Nov  6 08:49:37 1994       ; ANSI C's asctime() format</p>
	 *
	 * @link http://www.w3.org/Protocols/rfc2616/rfc2616-sec3.html
	 */
	static Date parseDateHeader(final String dateHeader) throws ParseException {
		final DateFormat[] rfc2626DateFormats = new DateFormat[] {
			new SimpleDateFormat("EEE, dd MMM yyyy HH:mm:ss z"),
			new SimpleDateFormat("EEEE, dd-MMM-yy HH:mm:ss z"),
			new SimpleDateFormat("EEE MMM d HH:mm:ss yyyy")
		};
		ParseException savedParseException = null;
		for (final DateFormat format : rfc2626DateFormats) {
			try {
				return format.parse(dateHeader);
			} catch (ParseException pe) {
				savedParseException = pe;
			}
		}
		assert savedParseException != null;
		throw savedParseException;
	}

	@Override
	public String toString() {
		return getTestType().toString();
	}

}
