// (c) COPYRIGHT MIT, INRIA and Keio, 2007 and onwards.
// Please first read the full copyright statement in file COPYRIGHT.html

package org.w3c.mwi.mobileok.basic;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

/**
 * Useful constants and methods related to building and parsing DOMs.
 */
final class DOMUtils {

	static final String NAMESPACE_DC = "http://purl.org/dc/elements/1.1/";
	static final String NAMESPACE_DCT = "http://purl.org/dc/terms/";	
	static final String NAMESPACE_EARL = "http://www.w3.org/WAI/ER/EARL/nmg-strawman#";
	static final String NAMESPACE_FOAF = "http://xmlns.com/foaf/0.1/";	
	static final String NAMESPACE_HTTP = "http://www.w3.org/2006/http#";
	static final String NAMESPACE_RDF = "http://www.w3.org/1999/02/22-rdf-syntax-ns#";
	static final String NAMESPACE_RFC822 = "http://www.w3.org/2006/rfc822#";
	static final String NAMESPACE_URI = "http://www.w3.org/2006/uri#";

	private DOMUtils() {}

	static Element addElementWithText(final Document document,
	                                  final Element parent,
	                                  final String namespace,
	                                  final String elementName,
	                                  final String value) {
		final Element child = document.createElementNS(namespace, elementName);
		parent.appendChild(child);
		if (value != null) {
			child.appendChild(document.createTextNode(value));
		}
		return child;
	}

	static Document newDOM() throws TestException {
		try {
			return DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();
		} catch (ParserConfigurationException pce) {
			throw new TestException(pce);
		}
	}

}
