// (c) COPYRIGHT MIT, INRIA and Keio, 2007 and onwards.
// Please first read the full copyright statement in file COPYRIGHT.html

package org.w3c.mwi.mobileok.basic;

import java.net.URI;
import java.nio.ByteBuffer;
import java.nio.charset.CharacterCodingException;
import java.nio.charset.Charset;
import java.nio.charset.CharsetDecoder;
import java.nio.charset.CodingErrorAction;
import java.util.Map;
import java.io.IOException;

class HTTPTextResource extends HTTPResource {

	private static final Charset UTF8_CHARSET = Charset.forName("UTF-8");

	private final String body;

	HTTPTextResource(final URI uri) throws IOException, TestException {
		super(uri);
		body = decodeBody(getRawBody());
	}

	HTTPTextResource(final URI uri, final Map<String, String> additionalRequestHeaders) throws IOException, TestException {
		super(uri, additionalRequestHeaders);
		body = decodeBody(getRawBody());
	}

	HTTPTextResource(final Integer httpStatus, final Map<String, String> httpHeaders, final byte[] rawBody)
		throws TestException {
		super(httpStatus, httpHeaders, rawBody);
		body = decodeBody(rawBody);

	}

	String getBody() {
		return body;
	}

	/**
	 * @param rawBody document body as bytes
	 * @return body as a {@link String} or <code>null</code> if it cannot be decoded as UTF-8
	 */
	private static String decodeBody(final byte[] rawBody) throws TestException {
		if (rawBody == null) {
			return null;
		}
		CharsetDecoder utf8Decoder = UTF8_CHARSET.newDecoder();
		utf8Decoder = utf8Decoder.onMalformedInput(CodingErrorAction.REPORT);
		utf8Decoder = utf8Decoder.onUnmappableCharacter(CodingErrorAction.REPORT);
		try {
			return utf8Decoder.decode(ByteBuffer.wrap(rawBody)).toString();
		} catch (CharacterCodingException cee) {
			throw new TestException(cee);
		}
	}

}
