// (c) COPYRIGHT MIT, INRIA and Keio, 2007 and onwards.
// Please first read the full copyright statement in file COPYRIGHT.html

package org.w3c.mwi.mobileok.basic;

import org.w3c.dom.Document;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import java.io.IOException;
import java.io.StringReader;

/**
 * {@link TestContext} encapsulates common state and information that is needed by all tests.
 * This includes, for example, the body of the resource being tested, and the {@link TestResults}
 * so far.
 */
final class TestContext {

	private final TestResults testResults;
	private final HTTPTextResource resource;
	private final Document dom;
	private final Document intermediateResultsDOM;

	TestContext(final HTTPTextResource resource) throws TestException {
		if (resource == null) {
			throw new IllegalArgumentException("resource or testResults is null");
		}
		this.resource = resource;
		// TODO needs to add more info in this doc beyond just HTTP-in-RDF section
		this.intermediateResultsDOM = resource.getRequestResponseDOM();
		this.testResults = new TestResults(resource.getURI(), intermediateResultsDOM);
		final String body = resource.getBody();
		if (body == null) {
			this.dom = DOMUtils.newDOM();
		} else {
			Document theDom;
			try {
				final DocumentBuilder builder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
				final InputSource stringSource = new InputSource(new StringReader(resource.getBody()));
				theDom = builder.parse(stringSource);
			} catch (ParserConfigurationException pce) {
				throw new TestException(pce);
			} catch (IOException ioe) {
				testResults.addGlobalWarning(ioe.getMessage());
				theDom = DOMUtils.newDOM();
			} catch (SAXException saxe) {
				testResults.addGlobalWarning(saxe.getMessage());
				theDom = DOMUtils.newDOM();
			}
			this.dom = theDom;
		}
	}

	HTTPResource getResourceContext() {
		return resource;
	}

	TestResults getTestResults() {
		return testResults;
	}

	Document getDOM() {
		return dom;
	}

	Document getIntermediateResultsDOM() {
		return intermediateResultsDOM;
	}

	void resetResults() {
		testResults.clear();
	}

}
