// (c) COPYRIGHT MIT, INRIA and Keio, 2007 and onwards.
// Please first read the full copyright statement in file COPYRIGHT.html

package org.w3c.mwi.mobileok.basic;

import java.util.ArrayList;
import java.util.List;

/**
 * Encapsulates the result of a single test.
 */
public final class TestResult {

	private final TestType type;
	private TestOutcome outcome;
	private String outcomeMessage;
	private final List<String> warnings;
	private final List<String> infos;

	TestResult(final TestType type) {
		if (type == null) {
			throw new IllegalArgumentException("type is null");
		}
		this.type = type;
		this.outcome = TestOutcome.PASS;
		this.warnings = new ArrayList<String>();
		this.infos = new ArrayList<String>();
	}

	public TestType getType() {
		return type;
	}

	void setOutcome(final TestOutcome outcome) {
		if (outcome == null) {
			throw new IllegalArgumentException("outcome is null");
		}
		this.outcome = outcome;
	}

	public TestOutcome getOutcome() {
		return outcome;
	}

	void setOutcomeMessage(final String outcomeMessage) {
		this.outcomeMessage = outcomeMessage;
	}

	public String getOutcomeMessage() {
		return outcomeMessage;
	}

	void addWarning(final String warning) {
		if (warning == null) {
			throw new IllegalArgumentException("warning is null");
		}
		warnings.add(warning);
	}

	public List<String> getWarnings() {
		return warnings;
	}

	void addInfo(final String info) {
		if (info == null) {
			throw new IllegalArgumentException("info is null");
		}
		infos.add(info);
	}

	public List<String> getInfos() {
		return infos;
	}

	@Override
	public String toString() {
		final StringBuilder result = new StringBuilder(512);
		result.append(type);
		result.append(": ");
		result.append(outcome);
		if (outcomeMessage != null) {
			result.append(": ");
			result.append(outcomeMessage);
		}
		result.append(AbstractTestImplementation.LINE_SEPARATOR);
		if (!warnings.isEmpty()) {
			result.append("WARNINGS:");
			result.append(AbstractTestImplementation.LINE_SEPARATOR);
			for (final String warning : warnings) {
				result.append('\t');
				result.append(warning);
				result.append(AbstractTestImplementation.LINE_SEPARATOR);
			}
		}
		if (!infos.isEmpty()) {
			result.append("INFO:");
			result.append(AbstractTestImplementation.LINE_SEPARATOR);
			for (final String info : infos) {
				result.append('\t');
				result.append(info);
				result.append(AbstractTestImplementation.LINE_SEPARATOR);
			}
		}
		return result.toString();
	}

}
