// (c) COPYRIGHT MIT, INRIA and Keio, 2007 and onwards.
// Please first read the full copyright statement in file COPYRIGHT.html

package org.w3c.mwi.mobileok.basic;

import java.util.Collections;
import java.util.EnumMap;
import java.util.Map;

/**
 * Enumerates all individual tests included in mobileOK Basic.
 */
public enum TestType {

	AUTO_REFRESH_REDIRECTION,
	CACHING,
	CHARACTER_ENCODING_SUPPORT,
	CONTENT_FORMAT_SUPPORT,
	DEFAULT_INPUT_MODE,
	EXTERNAL_RESOURCES,
	GRAPHICS_FOR_SPACING,
	IMAGE_MAPS,
	IMAGES_RESIZING_IMAGES_SPECIFY_SIZE,
	LARGE_GRAPHICS,
	LINK_TARGET_FORMAT,
	MEASURES,
	MINIMIZE,
	NO_FRAMES,
	NON_TEXT_ALTERNATIVES,
	OBJECTS_OR_SCRIPT,
	PAGE_SIZE_LIMIT,
	PAGE_TITLE,
	POP_UPS,
	PROVIDE_DEFAULTS,
	SCROLLING,
	STYLE_SHEETS_SUPPORT,
	STYLE_SHEETS_USE,
	TABLES_ALTERNATIVES,
	TABLES_LAYOUT,
	TABLES_NESTED,
	VALID_MARKUP;

	private static final Map<TestType, TestImplementation> implementations;

	static {
		final Map<TestType, TestImplementation> temp =
			new EnumMap<TestType, TestImplementation>(TestType.class);
		temp.put(AUTO_REFRESH_REDIRECTION, new AutoRefreshRedirectionTest());
		temp.put(CACHING, new CachingTest());
		temp.put(CHARACTER_ENCODING_SUPPORT, new CharacterEncodingSupportTest());
		temp.put(CONTENT_FORMAT_SUPPORT, new ContentFormatSupportTest());
		temp.put(DEFAULT_INPUT_MODE, new DefaultInputModeTest());
		temp.put(EXTERNAL_RESOURCES, new ExternalResourcesTest());
		temp.put(GRAPHICS_FOR_SPACING, new GraphicsForSpacingTest());
		temp.put(IMAGE_MAPS, new ImageMapsTest());
		temp.put(IMAGES_RESIZING_IMAGES_SPECIFY_SIZE, new ImagesResizingImagesSpecifySizeTest());
		temp.put(LARGE_GRAPHICS, new LargeGraphicsTest());
		temp.put(LINK_TARGET_FORMAT, new LinkTargetFormatTest());
		temp.put(MEASURES, new MeasuresTest());
		temp.put(MINIMIZE, new MinimizeTest());
		temp.put(NO_FRAMES, new NoFramesTest());
		temp.put(NON_TEXT_ALTERNATIVES, new NonTextAlternativesTest());
		temp.put(OBJECTS_OR_SCRIPT, new ObjectsOrScriptTest());
		temp.put(PAGE_SIZE_LIMIT, new PageSizeLimitTest());
		temp.put(PAGE_TITLE, new PageTitleTest());
		temp.put(POP_UPS, new PopUpsTest());
		temp.put(PROVIDE_DEFAULTS, new ProvideDefaultsTest());
		temp.put(SCROLLING, new ScrollingTest());
		temp.put(STYLE_SHEETS_SUPPORT, new StyleSheetsSupportTest());
		temp.put(STYLE_SHEETS_USE, new StyleSheetsUseTest());
		temp.put(TABLES_ALTERNATIVES, new TablesAlternativesTest());
		temp.put(TABLES_LAYOUT, new TablesLayoutTest());
		temp.put(TABLES_NESTED, new TablesNestedTest());
		temp.put(VALID_MARKUP, new ValidMarkupTest());

		implementations = Collections.unmodifiableMap(temp);
	}

	static TestImplementation getImplementation(final TestType type) {
		final TestImplementation implementation = implementations.get(type);
		assert implementation != null;
		return implementation;
	}

}
